
SpamPolicyWindow = class(BaseWindow);

-- Initializes a new SpamPolicyWindow instance
function SpamPolicyWindow:Constructor(viewModel)
	BaseWindow.Constructor(self);
	self.ViewModel = viewModel;

	local bindings = {
		["ResetNoSpamButtonClick"] = self.ViewModel.ResetNoSpamCommand,
		["ResetIsSpamButtonClick"] = self.ViewModel.ResetIsSpamCommand,
		["AutoRefreshChecked"] = self.ViewModel.AutoRefresh,
		["AutoRefreshCheckedChanged"] = function(sender, args)
			self.ViewModel:SetAutoRefresh(sender:IsChecked());
		end,
		["NoSpamText"] = table.concat(self.ViewModel.NoSpamWordsTable, "\n"),
		["IsSpamText"] = table.concat(self.ViewModel.IsSpamWordsTable, "\n"),
		["NumNoSpamWords"] = self.ViewModel.NumNoSpamWords,
		["NumIsSpamWords"] = self.ViewModel.NumIsSpamWords,
		["NumNoSpamWordEntries"] = self.ViewModel.NumNoSpamWordEntries,
		["NumIsSpamWordEntries"] = self.ViewModel.NumIsSpamWordEntries,
	};

	local content = TemplateLoader.Setup(self, self:GetTemplate(bindings));
	self:SetContent(content);
	self:SetText(self.ViewModel.Title);
	self:FitToContent();

	self.ViewModel:OnPropertyChanged("AutoRefresh", function(sender)
		self.AutoRefreshCheckBox:SetChecked(sender.AutoRefresh);
	end);

	self.ViewModel:OnPropertyChanged("NoSpamWordsTable", function(sender)
		self.NoSpamTextBlock:SetText(table.concat(sender.NoSpamWordsTable, "\n"));
	end);
	
	self.ViewModel:OnPropertyChanged("IsSpamWordsTable", function(sender)
		self.IsSpamTextBlock:SetText(table.concat(sender.IsSpamWordsTable, "\n"));
	end);
	
	self.ViewModel:OnPropertyChanged("NumNoSpamWords", function()
		self.NumNoSpamWordsTextBlock:SetText(self.ViewModel.NumNoSpamWords);
	end);

	self.ViewModel:OnPropertyChanged("NumIsSpamWords", function()
		self.NumIsSpamWordsTextBlock:SetText(self.ViewModel.NumIsSpamWords);
	end);
	
	self.ViewModel:OnPropertyChanged("NumNoSpamWordEntries", function()
		self.NumNoSpamWordEntriesTextBlock:SetText(self.ViewModel.NumNoSpamWordEntries);
	end);
	
	self.ViewModel:OnPropertyChanged("NumIsSpamWordEntries", function()
		self.NumIsSpamWordEntriesTextBlock:SetText(self.ViewModel.NumIsSpamWordEntries);
	end);
end

function SpamPolicyWindow:Closing(args)
	self.ViewModel:Destroy();
	BaseWindow.Closing(self, args);
end

function SpamPolicyWindow:GetTemplate(bindings)
	return {
		["Type"] = StackPanel,
		["Width"] = 550,
		["Height"] = 450,
		["FitToContent"] = false,
		["Content"] =
		{
			{
				["Type"] = StackPanel,
				["IsVertical"] = false,
				["Content.DynamicHeight"] = 1,
				["Content"] = 
				{
					{
						["Type"] = StackPanel,
						["Content.DynamicWidth"] = 1,
						["Content"] =
						{
							{
								["Type"] = TextBlock,
								["Text"] = "No Spam",
							},
							{
								["Type"] = Border,
								["BorderWidth"] = {Left = 10, Top = 10, Bottom = 10},
								["BorderColor"] = Turbine.UI.Color(0.98, 0.1, 0.2, 0.1),
								["Content.DynamicHeight"] = 1,
								["Content"] = 
								{
									{
										["Type"] = TextBlock,
										["Name"] = "NoSpamTextBlock",
										["Text"] = bindings["NoSpamText"],
										["AutoSize"] = false;
										["TextPadding"] = 4,
										["ScrollbarColor"] = Turbine.UI.Color(0.98, 0.1, 0.2, 0.1),
										["Content.BackColor"] = Turbine.UI.Color(0.98, 0.2, 0.3, 0.2),
										["Content.DynamicHeight"] = 1,
									},
								},
							},
{
								["Type"] = StackPanel,
								["IsVertical"] = false,
								["Content.PaddingTop"] = 10,
								["Content"] =
								{
									{
										["Type"] = TextBlock,
										["Text"] = "Counter",
										["Content.DynamicWidth"] = 1,
									},
									{
										["Type"] = TextBlock,
										["Text"] = bindings["NumNoSpamWords"],
										["Name"] = "NumNoSpamWordsTextBlock",
										["Content.DynamicWidth"] = 1,
									},
								}
							},
							{
								["Type"] = StackPanel,
								["IsVertical"] = false,
								["Content"] =
								{
									{
										["Type"] = TextBlock,
										["Text"] = "Words",
										["Content.DynamicWidth"] = 1,
									},
									{
										["Type"] = TextBlock,
										["Text"] = bindings["NumNoSpamWordEntries"],
										["Name"] = "NumNoSpamWordEntriesTextBlock",
										["Content.DynamicWidth"] = 1,
									},
								}
							},
						    {
								["Type"] = Button,
								["Text"] = "Reset",
								["Content.PaddingTop"] = 10,
								["Content.DynamicWidth"] = 1,
								["Click"] = bindings["ResetNoSpamButtonClick"],
							},
						},
					},
					{
						["Type"] = Border,
						["Width"] = 10,
					},
					{
						["Type"] = StackPanel,
						["Content.DynamicWidth"] = 1,
						["Content"] =
						{
							{
								["Type"] = TextBlock,
								["Text"] = "Spam",
							},
							{
								["Type"] = Border,
								["BorderWidth"] = {Left = 10, Top = 10, Bottom = 10},
								["BorderColor"] = Turbine.UI.Color(0.98, 0.2, 0.1, 0.1),
								["Content.DynamicHeight"] = 1,
								["Content"] = 
								{
									{
										["Type"] = TextBlock,
										["Name"] = "IsSpamTextBlock",
										["Text"] = bindings["IsSpamText"],
										["AutoSize"] = false;
										["TextPadding"] = 4,
										["ScrollbarColor"] = Turbine.UI.Color(0.98, 0.2, 0.1, 0.1),
										["Content.BackColor"] = Turbine.UI.Color(0.98, 0.3, 0.2, 0.2),
										["Content.DynamicHeight"] = 1,
									},
								},
							},
							{
								["Type"] = StackPanel,
								["IsVertical"] = false,
								["Content.PaddingTop"] = 10,
								["Content"] =
								{
									{
										["Type"] = TextBlock,
										["Text"] = "Counter",
										["Content.DynamicWidth"] = 1,
									},
									{
										["Type"] = TextBlock,
										["Text"] = bindings["NumIsSpamWords"],
										["Name"] = "NumIsSpamWordsTextBlock",
										["Content.DynamicWidth"] = 1,
									},
								}
							},
							{
								["Type"] = StackPanel,
								["IsVertical"] = false,
								["Content"] =
								{
									{
										["Type"] = TextBlock,
										["Text"] = "Words",
										["Content.DynamicWidth"] = 1,
									},
									{
										["Type"] = TextBlock,
										["Text"] = bindings["NumIsSpamWordEntries"],
										["Name"] = "NumIsSpamWordEntriesTextBlock",
										["Content.DynamicWidth"] = 1,
									},
								}
							},
						    {
								["Type"] = Button,
								["Text"] = "Reset",
								["Content.PaddingTop"] = 10,
								["Content.DynamicWidth"] = 1,
								["Click"] = bindings["ResetIsSpamButtonClick"],
							},
						},
					},
				},
			},
			{
				["Type"] = Border,
				["BorderWidth"] = {["Top"] = 1},
				["Content.PaddingTop"] = 10,
				["Content.PaddingBottom"] = 10,
			},
			{
				["Type"] = CheckBox,
				["Name"] = "AutoRefreshCheckBox",
				["Text"] = "Auto Refresh",
				["Checked"] = bindings["AutoRefreshChecked"],
				["CheckedChanged"] = bindings["AutoRefreshCheckedChanged"],
			},
		},
	};
end
